@@ -8,6 +8,7 @@
 ##
 import re
 import os
+import stat
 import logging
 import datetime
 import time
@@ -20,6 +21,7 @@ import platform
 import importlib
 from collections import namedtuple
 from enum import Enum as StdEnum
+import locale
 
 
 def Enum(*args):
@@ -79,14 +81,15 @@ class PropagatingThread(threading.Thread):
 #
 #  http://stackoverflow.com/questions/19423008/logged-subprocess-communicate
 ####
-def reader(filepath, outstream, stream, logging_level=logging.INFO):
+def reader(filepath, outstream, stream, logging_level=logging.INFO, encodingErrors='strict'):
     f = None
     # open file if caller provided path
     if(filepath):
         f = open(filepath, "w")
 
+    (_, encoding) = locale.getdefaultlocale()
     while True:
-        s = stream.readline().decode()
+        s = stream.readline().decode(encoding, errors=encodingErrors)
         if not s:
             break
         if(f is not None):
@@ -162,11 +165,13 @@ def timing(f):
 # @param logging_level - log level to log output at.  Default is INFO
 # @param raise_exception_on_nonzero - Setting to true causes exception to be raised if the cmd
 #                                     return code is not zero.
+# @param encodingErrors - may be given to set the desired error handling for encoding errors decoding cmd output.
+#                         Default is 'strict'.
 #
 # @return returncode of called cmd
 ####
 def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstream=None, environ=None,
-           logging_level=logging.INFO, raise_exception_on_nonzero=False):
+           logging_level=logging.INFO, raise_exception_on_nonzero=False, encodingErrors='strict'):
     cmd = cmd.strip('"\'')
     if " " in cmd:
         cmd = '"' + cmd + '"'
@@ -180,7 +185,7 @@ def RunCmd(cmd, parameters, capture=True, workingdir=None, outfile=None, outstre
     logging.log(logging_level, "------------------------------------------------")
     c = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, cwd=workingdir, shell=True, env=environ)
     if(capture):
-        thread = PropagatingThread(target=reader, args=(outfile, outstream, c.stdout, logging_level))
+        thread = PropagatingThread(target=reader, args=(outfile, outstream, c.stdout, logging_level, encodingErrors))
         thread.start()
         c.wait()
         thread.join()
@@ -432,12 +437,29 @@ def locate_class_in_module(Module, DesiredClass):
     return DesiredClassInstance
 
 
-if __name__ == '__main__':
-    pass
-    # Test code for printing a byte buffer
-    # a = [0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x3b, 0x3c, 0x3d]
-    # index = 0x55
-    # while(index < 0x65):
-    #     a.append(index)
-    #     PrintByteList(a)
-    #     index += 1
+def RemoveTree(dir_path: str, ignore_errors: bool = False) -> None:
+    '''
+    Helper for removing a directory.  Over time there have been
+    many private implementations of this due to reliability issues in the
+    shutil implementations.  To consolidate on a single function this helper is added.
+
+    On error try to change file attributes.  Also add retry logic.
+
+    dir_path: Path to directory to remove.
+    ignore_errors: ignore errors during removal
+    '''
+
+    def remove_readonly(func, path, _):
+        ''' private function to attempt to change permissions on file/folder being deleted'''
+        os.chmod(path, stat.S_IWRITE)
+        func(path)
+
+    for _ in range(3):  # retry up to 3 times
+        try:
+            shutil.rmtree(dir_path, ignore_errors=ignore_errors, onerror=remove_readonly)
+        except OSError as err:
+            logging.warning(f"Failed to fully remove {dir_path}: {err}")
+        else:
+            break
+    else:
+        raise RuntimeError(f"Failed to remove {dir_path}")
